==> SyL-0.12.1.tar.gz: SyL/example/examples/webapp/app/example/actions/example1/Index.php <==
<?php
/**
 * Хǡޥ͡
 */
SyL_Loader::lib('ValidationManager');

/** 
 * ͸ڡʥХǡ˥ץ륯饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: Index.php,v 1.1 2007/07/08 04:22:38 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class Example1_Index
{
    var $prefectures = array(
      '01' => '̳ƻ',
      '02' => 'Ŀ',
      '03' => '긩',
      '04' => 'ܾ븩',
      '05' => 'ĸ',
      '06' => '',
      '07' => 'ʡ縩',
      '08' => '븩',
      '09' => 'ڸ',
      '10' => 'ϸ',
      '11' => '̸',
      '12' => 'ո',
      '13' => '',
      '14' => '',
      '15' => '㸩',
      '16' => 'ٻ',
      '17' => '',
      '18' => 'ʡ温',
      '19' => '',
      '20' => 'Ĺ',
      '21' => '츩',
      '22' => 'Ų',
      '23' => 'θ',
      '24' => 'Ÿ',
      '25' => '츩',
      '26' => '',
      '27' => '',
      '28' => 'ʼ˸',
      '29' => 'ɸ',
      '30' => '²λ',
      '31' => 'Ļ踩',
      '32' => '纬',
      '33' => '',
      '34' => '縩',
      '35' => '',
      '36' => '縩',
      '37' => '',
      '38' => 'ɲ',
      '39' => 'θ',
      '40' => 'ʡ',
      '41' => '츩',
      '42' => 'Ĺ긩',
      '43' => 'ܸ',
      '44' => 'ʬ',
      '45' => 'ܺ긩',
      '46' => '縩',
      '47' => '츩'
    );

    /**
     * 󥹥ȥ饯
     *
     * @access public
     */
    function Example1_Index()
    {
        // νҤǤޤ
    }

    /**
     * ᥽å
     *
     * @access public
     * @param object ꥯȥ֥
     * @param object ǡ֥
     */
    function execute(&$data, &$context)
    {
        // եͽ
        $data->set('error_messages', array());
        $data->set('prefectures', $this->prefectures);

        $data->set('lastname',    $data->get('lastname'));
        $data->set('firstname',   $data->get('firstname'));
        $data->set('gender',      $data->get('gender'));
        $data->set('prefecture',  $data->get('prefecture'));
        $data->set('tel',         $data->get('tel'));
        $data->set('mailaddress', $data->get('mailaddress'));
        $data->set('blowser',     $data->get('blowser'));

        $data->set('valid', false);

        if ($context->isPost()) {
            // ϤΥݥȥХå

            // Хǡޥ͡㥪֥Ⱥ
            $validation_manager =& new SyL_ValidationManager();

            // Хǡܥѥ
            $v_require  =& SyL_Validator::create('require', '{name}ɬܤǤ');
            $v_numeric  =& SyL_Validator::create('numeric', '{name}ϿͤϤƤ');
            $v_length6  =& SyL_Validator::create('length',  '{name}Ϻ{max}ʸʥХȡˤޤϤǤޤ', array('max'=> 6));
            $v_length20 =& SyL_Validator::create('length',  '{name}Ϻ{max}ʸʥХȡˤޤϤǤޤ', array('max'=> 20));
            $v_email    =& SyL_Validator::create('email',   '{name}ηޤ');
            $v_regextel =& SyL_Validator::create('regex',   '{name}ޤ', array('format'=> '/^[0-9]+\-[0-9]+\-[0-9]{4}$/'));

            // -----------------------------------
            // ڥ롼ץѥ
            // -----------------------------------

            // ϹܥХǡѥ롼׺Хǡɲ
            $vs =& SyL_Validators::create();
            $vs->add($v_require);
            $vs->add($v_length20);
            $validation_manager->add($vs, $data->get('lastname'),  'lastname',  '̾');
            $validation_manager->add($vs, $data->get('firstname'), 'firstname', '̾̾');

            $vs =& SyL_Validators::create();
            $vs->add($v_require);
            $validation_manager->add($vs, $data->get('gender'), 'gender', '');
            $validation_manager->add($vs, $data->get('prefecture'), 'prefecture', 'ƻܸ');

            $vs =& SyL_Validators::create();
            $vs->add($v_regextel);
            $validation_manager->add($vs, $data->get('tel'), 'tel', 'ֹ');

            $vs =& SyL_Validators::create();
            $vs->add($v_require);
            $vs->add($v_email);
            $validation_manager->add($vs, $data->get('mailaddress'), 'mailaddress', '᡼륢ɥ쥹');

/*
            // -----------------------------------
            // ̸ڥѥ
            // -----------------------------------

            // ϹܤФơХǡܥѥ¹
            $validation_manager->add($v_require,  $data->get('lastname'),  'lastname1', '̾');
            $validation_manager->add($v_length20, $data->get('lastname'),  'lastname2', '̾');
            $validation_manager->add($v_require,  $data->get('firstname'), 'firstname1', '̾̾');
            $validation_manager->add($v_length20, $data->get('firstname'), 'firstname2', '̾̾');

            $validation_manager->add($v_require, $data->get('gender'), 'gender', '');

            $validation_manager->add($v_require, $data->get('prefecture'), 'prefecture', 'ƻܸ');

            $validation_manager->add($v_numeric, $data->get('tel1'), 'tel1',  'ֹ1');
            $validation_manager->add($v_length6, $data->get('tel1'), 'tel11', 'ֹ1');
            $validation_manager->add($v_numeric, $data->get('tel2'), 'tel2',  'ֹ2');
            $validation_manager->add($v_length6, $data->get('tel2'), 'tel21', 'ֹ2');
            $validation_manager->add($v_numeric, $data->get('tel3'), 'tel3',  'ֹ3');
            $validation_manager->add($v_length6, $data->get('tel3'), 'tel31', 'ֹ3');

            $validation_manager->add($v_require,   $data->get('mailaddress'), 'mailaddress1', '᡼륢ɥ쥹');
            $validation_manager->add($v_email, $data->get('mailaddress'), 'mailaddress2', '᡼륢ɥ쥹');
*/
            // Хǡ¹
            if ($validation_manager->execute()) {
                $data->set('valid', true);
            } else {
              // 顼ξ硢顼å
              $data->set('error_messages', $validation_manager->getErrorMessageAll());
            }
        }
    }

}

?>

==> SyL-0.13.1.tar.gz: SyL/example/examples/webapp/app/example/actions/example1/Index.php <==
<?php
/**
 * Хǡޥ͡
 */
SyL_Loader::lib('ValidationManager');

/** 
 * ͸ڡʥХǡ˥ץ륯饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: Index.php,v 1.2 2007/08/08 12:25:21 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class Example1_Index
{
    var $prefectures = array(
      '01' => '̳ƻ',
      '02' => 'Ŀ',
      '03' => '긩',
      '04' => 'ܾ븩',
      '05' => 'ĸ',
      '06' => '',
      '07' => 'ʡ縩',
      '08' => '븩',
      '09' => 'ڸ',
      '10' => 'ϸ',
      '11' => '̸',
      '12' => 'ո',
      '13' => '',
      '14' => '',
      '15' => '㸩',
      '16' => 'ٻ',
      '17' => '',
      '18' => 'ʡ温',
      '19' => '',
      '20' => 'Ĺ',
      '21' => '츩',
      '22' => 'Ų',
      '23' => 'θ',
      '24' => 'Ÿ',
      '25' => '츩',
      '26' => '',
      '27' => '',
      '28' => 'ʼ˸',
      '29' => 'ɸ',
      '30' => '²λ',
      '31' => 'Ļ踩',
      '32' => '纬',
      '33' => '',
      '34' => '縩',
      '35' => '',
      '36' => '縩',
      '37' => '',
      '38' => 'ɲ',
      '39' => 'θ',
      '40' => 'ʡ',
      '41' => '츩',
      '42' => 'Ĺ긩',
      '43' => 'ܸ',
      '44' => 'ʬ',
      '45' => 'ܺ긩',
      '46' => '縩',
      '47' => '츩'
    );

    /**
     * 󥹥ȥ饯
     *
     * @access public
     */
    function Example1_Index()
    {
        // νҤǤޤ
    }

    /**
     * ᥽å
     *
     * @access public
     * @param object ꥯȥ֥
     * @param object ǡ֥
     */
    function execute(&$data, &$context)
    {
        // եͽ
        $data->set('error_messages', array());
        $data->set('prefectures', $this->prefectures);

        $data->throwInput('lastname');
        $data->throwInput('firstname');
        $data->throwInput('gender');
        $data->throwInput('prefecture');
        $data->throwInput('tel');
        $data->throwInput('mailaddress');
        $data->throwInput('blowser');

        $data->set('valid', false);

        if ($context->isPost()) {
            // ϤΥݥȥХå

            // Хǡޥ͡㥪֥Ⱥ
            $validation_manager =& new SyL_ValidationManager();

            // Хǡܥѥ
            $v_require  =& SyL_Validator::create('require', '{name}ɬܤǤ');
            $v_numeric  =& SyL_Validator::create('numeric', '{name}ϿͤϤƤ');
            $v_length6  =& SyL_Validator::create('length',  '{name}Ϻ{max}ʸʥХȡˤޤϤǤޤ', array('max'=> 6));
            $v_length20 =& SyL_Validator::create('length',  '{name}Ϻ{max}ʸʥХȡˤޤϤǤޤ', array('max'=> 20));
            $v_email    =& SyL_Validator::create('email',   '{name}ηޤ');
            $v_regextel =& SyL_Validator::create('regex',   '{name}ޤ', array('format'=> '/^[0-9]+\-[0-9]+\-[0-9]{4}$/'));

            // -----------------------------------
            // ڥ롼ץѥ
            // -----------------------------------

            // ϹܥХǡѥ롼׺Хǡɲ
            $vs =& SyL_Validators::create();
            $vs->add($v_require);
            $vs->add($v_length20);
            $validation_manager->add($vs, $data->get('lastname'),  'lastname',  '̾');
            $validation_manager->add($vs, $data->get('firstname'), 'firstname', '̾̾');

            $vs =& SyL_Validators::create();
            $vs->add($v_require);
            $validation_manager->add($vs, $data->get('gender'), 'gender', '');
            $validation_manager->add($vs, $data->get('prefecture'), 'prefecture', 'ƻܸ');

            $vs =& SyL_Validators::create();
            $vs->add($v_regextel);
            $validation_manager->add($vs, $data->get('tel'), 'tel', 'ֹ');

            $vs =& SyL_Validators::create();
            $vs->add($v_require);
            $vs->add($v_email);
            $validation_manager->add($vs, $data->get('mailaddress'), 'mailaddress', '᡼륢ɥ쥹');

/*
            // -----------------------------------
            // ̸ڥѥ
            // -----------------------------------

            // ϹܤФơХǡܥѥ¹
            $validation_manager->add($v_require,  $data->get('lastname'),  'lastname1', '̾');
            $validation_manager->add($v_length20, $data->get('lastname'),  'lastname2', '̾');
            $validation_manager->add($v_require,  $data->get('firstname'), 'firstname1', '̾̾');
            $validation_manager->add($v_length20, $data->get('firstname'), 'firstname2', '̾̾');

            $validation_manager->add($v_require, $data->get('gender'), 'gender', '');

            $validation_manager->add($v_require, $data->get('prefecture'), 'prefecture', 'ƻܸ');

            $validation_manager->add($v_numeric, $data->get('tel1'), 'tel1',  'ֹ1');
            $validation_manager->add($v_length6, $data->get('tel1'), 'tel11', 'ֹ1');
            $validation_manager->add($v_numeric, $data->get('tel2'), 'tel2',  'ֹ2');
            $validation_manager->add($v_length6, $data->get('tel2'), 'tel21', 'ֹ2');
            $validation_manager->add($v_numeric, $data->get('tel3'), 'tel3',  'ֹ3');
            $validation_manager->add($v_length6, $data->get('tel3'), 'tel31', 'ֹ3');

            $validation_manager->add($v_require,   $data->get('mailaddress'), 'mailaddress1', '᡼륢ɥ쥹');
            $validation_manager->add($v_email, $data->get('mailaddress'), 'mailaddress2', '᡼륢ɥ쥹');
*/
            // Хǡ¹
            if ($validation_manager->execute()) {
                $data->set('valid', true);
            } else {
              // 顼ξ硢顼å
              $data->set('error_messages', $validation_manager->getErrorMessageAll());
            }
        }
    }

}

?>
